deviancep: Calculates the probability of obtaining the deviance value or...

View source: R/deviancep.R

deviancepR Documentation

Calculates the probability of obtaining the deviance value or larger if the parametric model holds deviancep calculates the probability of obtaining the deviance value or larger if the parametric model holds.

Description

Calculates the probability of obtaining the deviance value or larger if the parametric model holds deviancep calculates the probability of obtaining the deviance value or larger if the parametric model holds.

Usage

deviancep(qp)

quickpsy documentation built on March 11, 2026, 5:06 p.m.

Related to deviancep in quickpsy...