View source: R/one_deviancep.R
| one_deviancep | R Documentation |
one_deviancep calculates the probability of obtaining the deviance value
or larger if the parametric model holds for one conditionCalculates the probability of obtaining the deviance value or larger if the
parametric model holds for one condition
one_deviancep calculates the probability of obtaining the deviance value
or larger if the parametric model holds for one condition
one_deviancep(d, groups, deviance)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.