one_logliksaturated: Creates the loglik for the saturated model for one condition...

View source: R/one_logliksaturated.R

one_logliksaturatedR Documentation

Creates the loglik for the saturated model for one condition one_logliksaturated creates the loglik for the saturated model for one condition one_loglik

Description

Creates the loglik for the saturated model for one condition one_logliksaturated creates the loglik for the saturated model for one condition one_loglik

Usage

one_logliksaturated(d, x, k, n, psyfunguesslapses, groups, par)

quickpsy documentation built on March 11, 2026, 5:06 p.m.