View source: R/one_parcomparisons.R
| one_parcomparisons | R Documentation |
one_parcomparisons Calculates the bootstrap confidence intervals for the
difference in the parameters for two groups for all possible pairs
of groups (for each parameter)Pair comparisons of the parameters using bootstrap (for each parameter)
one_parcomparisons Calculates the bootstrap confidence intervals for the
difference in the parameters for two groups for all possible pairs
of groups (for each parameter)
one_parcomparisons(d, para, groups, ci)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.