one_thresholdcomparisons: Pair comparisons of the thresholds using bootstrap...

View source: R/one_thresholdcomparisons.R

one_thresholdcomparisonsR Documentation

Pair comparisons of the thresholds using bootstrap one_thresholdcomparisons Calculates the bootstrap confidence intervals for the difference in the thresholds for two groups for all possible pairs of groups

Description

Pair comparisons of the thresholds using bootstrap one_thresholdcomparisons Calculates the bootstrap confidence intervals for the difference in the thresholds for two groups for all possible pairs of groups

Usage

one_thresholdcomparisons(d, thresholds, groups, ci)

quickpsy documentation built on March 11, 2026, 5:06 p.m.