one_thresholdsci: Calculates the confidence intervals for the threshold of one...

View source: R/one_thresholdsci.R

one_thresholdsciR Documentation

Calculates the confidence intervals for the threshold of one condition one_thresholdsci calculates the confidence intervals for the threshold of one condition

Description

Calculates the confidence intervals for the threshold of one condition one_thresholdsci calculates the confidence intervals for the threshold of one condition

Usage

one_thresholdsci(d, ci, method)

quickpsy documentation built on March 11, 2026, 5:06 p.m.