one_ypred: Calculate the predictions of the response variable for one...

View source: R/one_ypred.R

one_ypredR Documentation

Calculate the predictions of the response variable for one condition one_ypred calculate the predictions of the response variable for one condition

Description

Calculate the predictions of the response variable for one condition one_ypred calculate the predictions of the response variable for one condition

Usage

one_ypred(d, log, groups, averages, x, psyfunguesslapses)

quickpsy documentation built on March 11, 2026, 5:06 p.m.

Related to one_ypred in quickpsy...