| plotcurves | R Documentation |
plotcurves plot the curves.
plotcurves(
qp,
panel = NULL,
xpanel = NULL,
ypanel = NULL,
color = NULL,
averages = T,
curves = T,
thresholds = T,
ci = T
)
qp |
output from quickpsy |
panel |
Name of the variable to be split in panels. |
xpanel |
Name of the variable to be split in horizontal panels. |
ypanel |
Name of the variable to be split in vertical panels. |
color |
Name of the variable codded by color. |
averages |
If |
curves |
If |
thresholds |
If |
ci |
If |
plotcurves_
library(MPDiR) # contains the Vernier data
fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
grouping = .(Direction, WaveForm, TempFreq), B = 5)
plotcurves(fit)
plotcurves(fit, xpanel = Direction)
plotcurves(fit, xpanel = Direction, color = WaveForm, ci = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.