| plotcurves_ | R Documentation |
plotcurves_ is the standard evaluation SE function associated
to the non-standard evaluation NSE function plotcurves.
SE functions can be more easily called from other functions.
In SE functions, you need to quote the names of the variables.
plotcurves_(
qp,
panel = NULL,
xpanel = NULL,
ypanel = NULL,
color = NULL,
averages = TRUE,
curves = TRUE,
thresholds = TRUE,
ci = TRUE
)
qp |
output from quickpsy |
panel |
Name of the variable to be split in panels. |
xpanel |
Name of the variable to be split in horizontal panels. |
ypanel |
Name of the variable to be split in vertical panels. |
color |
Name of the variable codded by color. |
averages |
If |
curves |
If |
thresholds |
If |
ci |
If |
plotcurves
library(MPDiR) # contains the Vernier data
data(Vernier) # ?Venier for the reference
fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
grouping = .(Direction, WaveForm, TempFreq), B = 5)
plotcurves_(fit, xpanel = 'Direction')
plotcurves_(fit, color = 'Direction')
plotcurves_(fit, xpanel = 'Direction', color = 'WaveForm', ci = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.