| plotpar_ | R Documentation |
plotpar_ is the standard evaluation SE function associated
to the non-standard evaluation NSE function plotpar.
SE functions can be more easily called from other functions.
In SE functions, you need to quote the names of the variables.
plotpar_(
qp,
x = NULL,
panel = NULL,
xpanel = NULL,
ypanel = NULL,
color = NULL,
geom = "bar",
ci = T
)
qp |
output from quickpsy. |
x |
Name of the variable to displayed in the x-axis. |
panel |
Name of the variable to be split in panels. |
xpanel |
Name of the variable to be split in horizontal panels. |
ypanel |
Name of the variable to be split in vertical panels. |
color |
Name of the variable codded by color. |
geom |
If |
ci |
If |
plotpar
library(MPDiR) # contains the Vernier data
fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
grouping = .(Direction, WaveForm, TempFreq), bootstrap = 'none')
plotpar_(fit, x = 'WaveForm')
plotpar_(fit, xpanel = 'Direction')
plotpar_(fit, color = 'Direction')
plotpar_(fit, color = 'Direction', ypanel = 'WaveForm', geom = 'point')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.