View source: R/plotthresholds.R
| plotthresholds | R Documentation |
plotthresholds plot the thresholds.
plotthresholds(
qp,
x = NULL,
panel = NULL,
xpanel = NULL,
ypanel = NULL,
color = NULL,
geom = "bar",
ci = T,
sizeerrorbar = 0.5
)
qp |
output from quickpsy. |
x |
Name of the variable to displayed in the x-axis. |
panel |
Name of the variable to be split in panels. |
xpanel |
Name of the variable to be split in horizontal panels. |
ypanel |
Name of the variable to be split in vertical panels. |
color |
Name of the variable codded by color. |
geom |
If |
ci |
If |
sizeerrorbar |
Line width of the error bars.
If |
plotthresholds_
library(MPDiR) # contains the Vernier data
fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
grouping = .(Direction, WaveForm, TempFreq), B = 10)
plotthresholds(fit)
plotthresholds(fit, x = WaveForm)
plotthresholds(fit, xpanel = Direction)
plotthresholds(fit, color = Direction, ypanel = WaveForm, geom = 'point')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.