View source: R/plotthresholds_.R
| plotthresholds_ | R Documentation |
plotthresholds_ is the standard evaluation SE function associated
to the non-standard evaluation NSE function plotthresholds.
SE functions can be more easily called from other functions.
In SE functions, you need to quote the names of the variables.
plotthresholds_(
qp,
x = NULL,
panel = NULL,
xpanel = NULL,
ypanel = NULL,
color = NULL,
geom = "bar",
ci = T,
sizeerrorbar = 0.5
)
qp |
output from quickpsy. |
x |
Name of the variable to displayed in the x-axis. |
panel |
Name of the variable to be split in panels. |
xpanel |
Name of the variable to be split in horizontal panels. |
ypanel |
Name of the variable to be split in vertical panels. |
color |
Name of the variable codded by color. |
geom |
If |
ci |
If |
sizeerrorbar |
Line width of the error bars.
If |
plotthresholds
library(MPDiR) # contains the Vernier data
fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
grouping = .(Direction, WaveForm, TempFreq), B = 10)
plotthresholds_(fit, x = 'WaveForm')
plotthresholds_(fit, xpanel = 'Direction')
plotthresholds_(fit, color = 'Direction')
plotthresholds_(fit, color = 'Direction', ypanel = 'WaveForm', geom = 'point')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.