summary.quickpsy: Plot the parameters and its confidence intervals 'summary'...

View source: R/summary.R

summary.quickpsyR Documentation

Plot the parameters and its confidence intervals summary Plot the parameters and its confidence intervals

Description

Plot the parameters and its confidence intervals summary Plot the parameters and its confidence intervals

Usage

## S3 method for class 'quickpsy'
summary(object, ...)

Arguments

object

An object for which a summary is desired.

...

Additional arguments affecting the summary produced.


quickpsy documentation built on March 11, 2026, 5:06 p.m.