thresholdcomparisons: Pair comparisons of the parameters using bootstrap...

View source: R/thresholdcomparisons.R

thresholdcomparisonsR Documentation

Pair comparisons of the parameters using bootstrap thresholdcomparisons Calculates the bootstrap confidence intervals for the difference in the parameters for two groups for all possible pairs of groups

Description

Pair comparisons of the parameters using bootstrap thresholdcomparisons Calculates the bootstrap confidence intervals for the difference in the parameters for two groups for all possible pairs of groups

Usage

thresholdcomparisons(qp, ci = 0.95)

quickpsy documentation built on March 11, 2026, 5:06 p.m.