View source: R/one_logliksaturated.R
| one_logliksaturated | R Documentation |
one_logliksaturated creates the loglik for the saturated model for one condition
one_loglikCreates the loglik for the saturated model for one condition
one_logliksaturated creates the loglik for the saturated model for one condition
one_loglik
one_logliksaturated(d, x, k, n, psyfunguesslapses, groups, par)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.