View source: R/one_thresholdcomparisons.R
| one_thresholdcomparisons | R Documentation |
one_thresholdcomparisons Calculates the bootstrap confidence intervals for the
difference in the thresholds for two groups for all possible pairs
of groupsPair comparisons of the thresholds using bootstrap
one_thresholdcomparisons Calculates the bootstrap confidence intervals for the
difference in the thresholds for two groups for all possible pairs
of groups
one_thresholdcomparisons(d, thresholds, groups, ci)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.