| one_ypred | R Documentation |
one_ypred calculate the predictions of the response variable for one
conditionCalculate the predictions of the response variable for one condition
one_ypred calculate the predictions of the response variable for one
condition
one_ypred(d, log, groups, averages, x, psyfunguesslapses)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.